@@ -37,29 +37,32 @@ from linaro_image_tools.hwpack.testing import (
     MatchesStructure,
     Not,
     )
+from linaro_image_tools.hwpack.hardwarepack_format import (
+    HardwarePackFormatV1,
+    HardwarePackFormatV2,
+    )
 
 
 class MetadataTests(TestCase):
+    def setUp(self):
+        super(MetadataTests, self).setUp()
+        self.metadata = Metadata("ahwpack", "3", "armel")
 
     def test_name(self):
-        metadata = Metadata("ahwpack", "3", "armel")
-        self.assertEqual("ahwpack", metadata.name)
+        self.assertEqual("ahwpack", self.metadata.name)
 
     def test_version(self):
-        metadata = Metadata("ahwpack", "3", "armel")
-        self.assertEqual("3", metadata.version)
+        self.assertEqual("3", self.metadata.version)
 
     def test_version_with_whitespace(self):
         self.assertRaises(
             AssertionError, Metadata, "ahwpack", "3 (with extras)", "armel")
 
     def test_architecture(self):
-        metadata = Metadata("ahwpack", "3", "armel")
-        self.assertEqual("armel", metadata.architecture)
+        self.assertEqual("armel", self.metadata.architecture)
 
     def test_default_origin_is_None(self):
-        metadata = Metadata("ahwpack", "4", "armel")
-        self.assertEqual(None, metadata.origin)
+        self.assertEqual(None, self.metadata.origin)
 
     def test_origin(self):
         metadata = Metadata("ahwpack", "4", "armel", origin="linaro")
@@ -108,12 +111,175 @@ class MetadataTests(TestCase):
             "SUPPORT=unsupported\n",
             str(metadata))
 
+    def test_str_with_serial_tty(self):
+        metadata = Metadata("ahwpack", "4", "armel",
+                            format=HardwarePackFormatV2())
+        metadata.add_v2_config(serial_tty='ttyO2')
+        self.assertEqual(
+            "NAME=ahwpack\nVERSION=4\nARCHITECTURE=armel\n"
+            "SERIAL_TTY=ttyO2\n",
+            str(metadata))
+
+    def test_str_with_kernel_addr(self):
+        metadata = Metadata("ahwpack", "4", "armel",
+                            format=HardwarePackFormatV2())
+        metadata.add_v2_config(kernel_addr='0x80000000')
+        self.assertEqual(
+            "NAME=ahwpack\nVERSION=4\nARCHITECTURE=armel\n"
+            "KERNEL_ADDR=0x80000000\n",
+            str(metadata))
+
+    def test_str_with_initrd_addr(self):
+        metadata = Metadata("ahwpack", "4", "armel",
+                            format=HardwarePackFormatV2())
+        metadata.add_v2_config(initrd_addr='0x80000000')
+        self.assertEqual(
+            "NAME=ahwpack\nVERSION=4\nARCHITECTURE=armel\n"
+            "INITRD_ADDR=0x80000000\n",
+            str(metadata))
+
+    def test_str_with_load_addr(self):
+        metadata = Metadata("ahwpack", "4", "armel",
+                            format=HardwarePackFormatV2())
+        metadata.add_v2_config(load_addr='0x80000000')
+        self.assertEqual(
+            "NAME=ahwpack\nVERSION=4\nARCHITECTURE=armel\n"
+            "LOAD_ADDR=0x80000000\n",
+            str(metadata))
+
+    def test_str_with_dtb_addr(self):
+        metadata = Metadata("ahwpack", "4", "armel",
+                            format=HardwarePackFormatV2())
+        metadata.add_v2_config(dtb_addr='0x80000000')
+        self.assertEqual(
+            "NAME=ahwpack\nVERSION=4\nARCHITECTURE=armel\n"
+            "DTB_ADDR=0x80000000\n",
+            str(metadata))
+
+    def test_str_with_wired_interfaces(self):
+        metadata = Metadata("ahwpack", "4", "armel",
+                            format=HardwarePackFormatV2())
+        metadata.add_v2_config(wired_interfaces=['eth0', 'usb0'])
+        self.assertEqual(
+            "NAME=ahwpack\nVERSION=4\nARCHITECTURE=armel\n"
+            "WIRED_INTERFACES=eth0 usb0\n",
+            str(metadata))
+
+    def test_str_with_wireless_interfaces(self):
+        metadata = Metadata("ahwpack", "4", "armel",
+                            format=HardwarePackFormatV2())
+        metadata.add_v2_config(wireless_interfaces=['wlan0', 'wl0'])
+        self.assertEqual(
+            "NAME=ahwpack\nVERSION=4\nARCHITECTURE=armel\n"
+            "WIRELESS_INTERFACES=wlan0 wl0\n",
+            str(metadata))
+
+    def test_str_with_partition_layout(self):
+        metadata = Metadata("ahwpack", "4", "armel",
+                            format=HardwarePackFormatV2())
+        metadata.add_v2_config(partition_layout='bootfs_rootfs')
+        self.assertEqual(
+            "NAME=ahwpack\nVERSION=4\nARCHITECTURE=armel\n"
+            "PARTITION_LAYOUT=bootfs_rootfs\n",
+            str(metadata))
+
+    def test_str_with_mmc_id(self):
+        metadata = Metadata("ahwpack", "4", "armel",
+                            format=HardwarePackFormatV2())
+        metadata.add_v2_config(mmc_id='1')
+        self.assertEqual(
+            "NAME=ahwpack\nVERSION=4\nARCHITECTURE=armel\n"
+            "MMC_ID=1\n",
+            str(metadata))
+
+    def test_str_with_boot_min_size(self):
+        metadata = Metadata("ahwpack", "4", "armel",
+                            format=HardwarePackFormatV2())
+        metadata.add_v2_config(boot_min_size='50')
+        self.assertEqual(
+            "NAME=ahwpack\nVERSION=4\nARCHITECTURE=armel\n"
+            "BOOT_MIN_SIZE=50\n",
+            str(metadata))
+
+    def test_str_with_root_min_size(self):
+        metadata = Metadata("ahwpack", "4", "armel",
+                            format=HardwarePackFormatV2())
+        metadata.add_v2_config(root_min_size='100')
+        self.assertEqual(
+            "NAME=ahwpack\nVERSION=4\nARCHITECTURE=armel\n"
+            "ROOT_MIN_SIZE=100\n",
+            str(metadata))
+
+    def test_str_with_loader_min_size(self):
+        metadata = Metadata("ahwpack", "4", "armel",
+                            format=HardwarePackFormatV2())
+        metadata.add_v2_config(loader_min_size='1')
+        self.assertEqual(
+            "NAME=ahwpack\nVERSION=4\nARCHITECTURE=armel\n"
+            "LOADER_MIN_SIZE=1\n",
+            str(metadata))
+
+    def test_str_with_kernel_file(self):
+        metadata = Metadata("ahwpack", "4", "armel",
+                            format=HardwarePackFormatV2())
+        metadata.add_v2_config(vmlinuz='boot/vmlinuz-3.0.0-1002-linaro-omap')
+        self.assertEqual(
+            "NAME=ahwpack\nVERSION=4\nARCHITECTURE=armel\n"
+            "KERNEL_FILE=boot/vmlinuz-3.0.0-1002-linaro-omap\n",
+            str(metadata))
+
+    def test_str_with_initrd_file(self):
+        metadata = Metadata("ahwpack", "4", "armel",
+                            format=HardwarePackFormatV2())
+        metadata.add_v2_config(initrd='boot/initrd.img-3.0.0-1002-linaro-omap')
+        self.assertEqual(
+            "NAME=ahwpack\nVERSION=4\nARCHITECTURE=armel\n"
+            "INITRD_FILE=boot/initrd.img-3.0.0-1002-linaro-omap\n",
+            str(metadata))
+
+    def test_str_with_dtb_file(self):
+        metadata = Metadata("ahwpack", "4", "armel",
+                            format=HardwarePackFormatV2())
+        metadata.add_v2_config(dtb_file='boot/dt-3.0.0-1002-linaro-omap/omap4-panda.dtb')
+        self.assertEqual(
+            "NAME=ahwpack\nVERSION=4\nARCHITECTURE=armel\n"
+            "DTB_FILE=boot/dt-3.0.0-1002-linaro-omap/omap4-panda.dtb\n",
+            str(metadata))
+
+    def test_str_with_boot_script(self):
+        metadata = Metadata("ahwpack", "4", "armel",
+                            format=HardwarePackFormatV2())
+        metadata.add_v2_config(boot_script='boot.scr')
+        self.assertEqual(
+            "NAME=ahwpack\nVERSION=4\nARCHITECTURE=armel\n"
+            "BOOT_SCRIPT=boot.scr\n",
+            str(metadata))
+
+    def test_str_with_extra_boot_options(self):
+        metadata = Metadata("ahwpack", "4", "armel",
+                            format=HardwarePackFormatV2())
+        metadata.add_v2_config(extra_boot_options='earlyprintk fixrtc nocompcache vram=48M omapfb.vram=0:24M mem=456M@0x80000000 mem=512M@0xA0000000')
+        self.assertEqual(
+            "NAME=ahwpack\nVERSION=4\nARCHITECTURE=armel\n"
+            "EXTRA_BOOT_OPTIONS=earlyprintk fixrtc nocompcache vram=48M omapfb.vram=0:24M mem=456M@0x80000000 mem=512M@0xA0000000\n",
+            str(metadata))
+
+    def test_str_with_extra_serial_options(self):
+        metadata = Metadata("ahwpack", "4", "armel",
+                            format=HardwarePackFormatV2())
+        metadata.add_v2_config(extra_serial_opts='console=tty0 console=ttyO2,115200n8')
+        self.assertEqual(
+            "NAME=ahwpack\nVERSION=4\nARCHITECTURE=armel\n"
+            "EXTRA_SERIAL_OPTIONS=console=tty0 console=ttyO2,115200n8\n",
+            str(metadata))
+
     def test_from_config(self):
         class Config:
             name = "foo"
             origin = "linaro"
             maintainer = "someone"
             support = "supported"
+            format = HardwarePackFormatV1()
         config = Config()
         metadata = Metadata.from_config(config, "2.0", "i386")
         self.assertEqual(config.name, metadata.name)
@@ -130,14 +296,15 @@ class HardwarePackTests(TestCase):
         super(HardwarePackTests, self).setUp()
         self.metadata = Metadata("ahwpack", "4", "armel")
 
-    def test_format_is_1_0(self):
+    def test_format_is_correct(self):
+        format = '1.0'
         hwpack = HardwarePack(self.metadata)
-        self.assertEqual("1.0", hwpack.FORMAT)
+        self.assertEqual(format, hwpack.format.__str__())
 
     def test_format_has_no_spaces(self):
         hwpack = HardwarePack(self.metadata)
-        self.assertIs(None, re.search('\s', hwpack.FORMAT),
-                      "hwpack.FORMAT contains spaces.")
+        self.assertIs(None, re.search('\s', hwpack.format.__str__()),
+                      "hwpack.format contains spaces.")
 
     def test_filename(self):
         hwpack = HardwarePack(self.metadata)
@@ -167,7 +334,7 @@ class HardwarePackTests(TestCase):
         tf = self.get_tarfile(hwpack)
         self.assertThat(
             tf,
-            HardwarePackHasFile("FORMAT", content=hwpack.FORMAT+"\n"))
+            HardwarePackHasFile("FORMAT", content=hwpack.format.__str__()+"\n"))
 
     def test_creates_metadata_file(self):
         metadata = Metadata(
