@@ -33,6 +33,7 @@ from linaro_image_tools.media_create.boards import SnowballSdConfig
 from linaro_image_tools.media_create.boards import SnowballEmmcConfig
 from linaro_image_tools.media_create.boards import SMDKV310Config
 from linaro_image_tools.media_create.boards import OrigenConfig
+from linaro_image_tools.media_create.boards import VexpressA9Config
 from linaro_image_tools.media_create.boards import (
     align_up,
     align_partition,
@@ -167,6 +168,7 @@ class AndroidBoardConfig(object):
     def install_boot_loader(cls, boot_partition, boot_device_or_file):
         pass
 
+
 class AndroidOmapConfig(AndroidBoardConfig):
     pass
 
@@ -185,21 +187,31 @@ class AndroidPandaConfig(AndroidOmapConfig, PandaConfig):
 
 
 class AndroidSnowballSdConfig(AndroidBoardConfig, SnowballSdConfig):
+    boot_script = 'boot.scr'
+    initrd_addr = '0x05000000'
     extra_boot_args_options = (
-        'earlyprintk rootdelay=1 fixrtc nocompcache '
-        'mem=128M@0 mali.mali_mem=64M@128M mem=24M@192M hwmem=167M@216M '
-        'mem_issw=1M@383M mem=640M@384M vmalloc=256M')
-    _extra_serial_opts = 'console=tty0 console=ttyO2,115200n8'
+        'earlyprintk mem=128M@0 mali.mali_mem=32M@128M hwmem=168M@160M mem=48M@328M mem_issw=1M@383M mem=640M@384M vmalloc=256M')
+    _extra_serial_opts = 'console=ttyAMA2,115200n8'
     android_specific_args = 'init=/init androidboot.console=ttyAMA2'
+    # Snowball uses a custom uboot:
+    # it uses "fat load" instead of fatload and
+    # needs uImage/uInitrd prefixed with /
+    fatload_command = 'fat load'
+    uimage_path = '/'
 
 
 class AndroidSnowballEmmcConfig(AndroidBoardConfig, SnowballEmmcConfig):
+    boot_script = 'boot.scr'
+    initrd_addr = '0x05000000'
     extra_boot_args_options = (
-        'earlyprintk rootdelay=1 fixrtc nocompcache '
-        'mem=128M@0 mali.mali_mem=64M@128M mem=24M@192M hwmem=167M@216M '
-        'mem_issw=1M@383M mem=640M@384M vmalloc=256M')
-    _extra_serial_opts = 'console=tty0 console=ttyAMA2,115200n8'
+        'earlyprintk mem=128M@0 mali.mali_mem=32M@128M hwmem=168M@160M mem=48M@328M mem_issw=1M@383M mem=640M@384M vmalloc=256M')
+    _extra_serial_opts = 'console=ttyAMA2,115200n8'
     android_specific_args = 'init=/init androidboot.console=ttyAMA2'
+    # Snowball uses a custom uboot:
+    # it uses "fat load" instead of fatload and
+    # needs uImage/uInitrd prefixed with /
+    fatload_command = 'fat load'
+    uimage_path = '/'
 
     @classmethod
     def get_sfdisk_cmd(cls, should_align_boot_part=False):
@@ -218,6 +230,7 @@ class AndroidSnowballEmmcConfig(AndroidBoardConfig, SnowballEmmcConfig):
         return '%s,%s,0xDA\n%s' % (
             loader_start, loader_len, command)
 
+
 class AndroidMx53LoCoConfig(AndroidBoardConfig, Mx53LoCoConfig):
     extra_boot_args_options = (
         'earlyprintk rootdelay=1 fixrtc nocompcache di1_primary tve')
@@ -272,6 +285,11 @@ class AndroidOrigenConfig(AndroidSamsungConfig, OrigenConfig):
     android_specific_args = 'init=/init androidboot.console=ttySAC2'
 
 
+class AndroidVexpressA9Config(AndroidBoardConfig, VexpressA9Config):
+    _extra_serial_opts = 'console=tty0 console=ttyAMA0,38400n8'
+    android_specific_args = 'init=/init androidboot.console=ttyAMA0'
+
+
 android_board_configs = {
     'beagle': AndroidBeagleConfig,
     'panda': AndroidPandaConfig,
@@ -281,4 +299,5 @@ android_board_configs = {
     'mx53loco': AndroidMx53LoCoConfig,
     'iMX53': AndroidMx53LoCoConfig,
     'origen': AndroidOrigenConfig,
+    'vexpress-a9': AndroidVexpressA9Config,
     }
