@@ -202,8 +202,10 @@ class BoardConfig(object):
     spl_in_boot_part = False
     spl_dd = False
     env_dd = False
+    fatload_command = 'fatload'
     mmc_option = '0:1'
     mmc_part_offset = 0
+    uimage_path = ''
     fat_size = 32
     _extra_serial_opts = ''
     _live_serial_opts = ''
@@ -552,17 +554,18 @@ class BoardConfig(object):
         In general subclasses should not have to override this.
         """
         replacements = dict(
+            fatload_command=cls.fatload_command, uimage_path=cls.uimage_path,
             mmc_option=cls.mmc_option, kernel_addr=cls.kernel_addr,
             initrd_addr=cls.initrd_addr, dtb_addr=cls.dtb_addr)
         boot_script = (
-            "fatload mmc %(mmc_option)s %(kernel_addr)s uImage; "
-            "fatload mmc %(mmc_option)s %(initrd_addr)s uInitrd; "
+            "%(fatload_command)s mmc %(mmc_option)s %(kernel_addr)s %(uimage_path)suImage; "
+            "%(fatload_command)s mmc %(mmc_option)s %(initrd_addr)s %(uimage_path)suInitrd; "
             % replacements)
         if d_img_data is not None:
             assert cls.dtb_addr is not None, (
                 "Need a dtb_addr when passing d_img_data")
             boot_script += (
-                "fatload mmc %(mmc_option)s %(dtb_addr)s board.dtb; "
+                "%(fatload_command)s mmc %(mmc_option)s %(dtb_addr)s board.dtb; "
                 "bootm %(kernel_addr)s %(initrd_addr)s %(dtb_addr)s"
                 % replacements)
         else:
@@ -1263,7 +1266,7 @@ class VexpressConfig(BoardConfig):
     initrd_addr = '0x81000000'
     load_addr = kernel_addr
     kernel_flavors = ['linaro-vexpress']
-    boot_script = None
+    boot_script = 'boot.scr'
     # ARM Boot Monitor is used to load u-boot, uImage etc. into flash and
     # only allows for FAT16
     fat_size = 16
@@ -1284,6 +1287,13 @@ class VexpressConfig(BoardConfig):
         make_uInitrd(i_img_data, boot_dir)
 
 
+class VexpressA9Config(VexpressConfig):
+    # For now, this is a duplicate of VexpressConfig.
+    # In future, there will also be A5 and A15 variants.
+    # For all of these, there should never be any V1 hardware packs.
+    pass
+
+
 class SamsungConfig(BoardConfig):
     @classproperty
     def extra_serial_opts(cls):
@@ -1427,6 +1437,7 @@ board_configs = {
     'igep': IgepConfig,
     'panda': PandaConfig,
     'vexpress': VexpressConfig,
+    'vexpress-a9': VexpressA9Config,
     'ux500': Ux500Config,
     'snowball_sd': SnowballSdConfig,
     'snowball_emmc': SnowballEmmcConfig,
